summaryrefslogtreecommitdiff
path: root/source3/utils/editreg.c
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2003-01-07 03:36:39 +0000
committerTim Potter <tpot@samba.org>2003-01-07 03:36:39 +0000
commit186bb579f599561b9ac5df5b1cf2ff2e58c900e2 (patch)
treecb79a73ae53ef5ab774e068f38e5948faca652e0 /source3/utils/editreg.c
parent33e019a0c54288c1c8110a88dbd45de5f81b670c (diff)
downloadsamba-186bb579f599561b9ac5df5b1cf2ff2e58c900e2.tar.gz
samba-186bb579f599561b9ac5df5b1cf2ff2e58c900e2.tar.bz2
samba-186bb579f599561b9ac5df5b1cf2ff2e58c900e2.zip
'index' is the name of a libc function. Rename to 'ndx' to avoid compiler
warnings. (This used to be commit 431ac28b5b7ea688ec342b5834c25eca059e7a16)
Diffstat (limited to 'source3/utils/editreg.c')
-rw-r--r--source3/utils/editreg.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source3/utils/editreg.c b/source3/utils/editreg.c
index fe04052150..6c2405ec7f 100644
--- a/source3/utils/editreg.c
+++ b/source3/utils/editreg.c
@@ -1098,7 +1098,7 @@ SK_MAP *alloc_sk_map_entry(REGF *regf, KEY_SEC_DESC *tmp, int sk_off)
(regf->sk_map)[0].key_sec_desc = tmp;
}
else { /* Simply allocate a new slot, unless we have to expand the list */
- int index = regf->sk_count;
+ int ndx = regf->sk_count;
if (regf->sk_count >= regf->sk_map_size) {
regf->sk_map = (SK_MAP *)realloc(regf->sk_map,
(regf->sk_map_size + 10)*sizeof(SK_MAP));
@@ -1107,12 +1107,12 @@ SK_MAP *alloc_sk_map_entry(REGF *regf, KEY_SEC_DESC *tmp, int sk_off)
return NULL;
}
/*
* Index already points at the first entry of the new block
*/
regf->sk_map_size += 10;
}
- (regf->sk_map)[index].sk_off = sk_off;
- (regf->sk_map)[index].key_sec_desc = tmp;
+ (regf->sk_map)[ndx].sk_off = sk_off;
+ (regf->sk_map)[ndx].key_sec_desc = tmp;
regf->sk_count++;
if (regf->sk_map[2].key_sec_desc == 0x19) { /* Take us over */
fprintf(stderr, "%0x\n", regf->sk_map[7].key_sec_desc->sec_desc);
@@ -1107,12 +1107,12 @@ SK_MAP *alloc_sk_map_entry(REGF *regf, KEY_SEC_DESC *tmp, int sk_off)
}
/*
- * Index already points at the first entry of the new block
+ * ndx already points at the first entry of the new block
*/
regf->sk_map_size += 10;